@@ -1,18 +1,7 @@
-/**
- * Copyright (c) Istituto Nazionale di Fisica Nucleare, 2006-2014.
- *
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- *
- *     http://www.apache.org/licenses/LICENSE-2.0
- *
- * Unless required by applicable law or agreed to in writing, software
- * distributed under the License is distributed on an "AS IS" BASIS,
- * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
- * See the License for the specific language governing permissions and
- * limitations under the License.
- */
+// SPDX-FileCopyrightText: 2006 Istituto Nazionale di Fisica Nucleare
+//
+// SPDX-License-Identifier: Apache-2.0
+
 package org.italiangrid.voms.clients.impl;
 
 import java.util.ArrayList;
@@ -23,11 +12,33 @@ import java.util.Map;
 
 import org.italiangrid.voms.clients.strategies.VOMSCommandsParsingStrategy;
 
+/**
+ * Default implementation of the {@link VOMSCommandsParsingStrategy} interface.
+ * This class is responsible for parsing VOMS commands into a structured format.
+ */
 public class DefaultVOMSCommandsParser implements VOMSCommandsParsingStrategy {
 
+  /**
+   * The character used to separate VO names from FQANs in command strings.
+   */
   public static final String COMMAND_SEPARATOR = ":";
+
+  /**
+   * The string representing a request for all available attributes.
+   */
   public static final String ALL_COMMAND_STRING = "all";
 
+  /**
+   * Parses a list of VOMS commands and organizes them into a map.
+   *
+   * @param commands A list of strings representing VOMS commands, where each
+   *                 command follows the format "vo[:fqan]".
+   * @return A map where the keys are VO names and the values are lists of
+   *         requested FQANs. If "all" is specified, no FQANs are added.
+   *         Returns {@code null} if the input list is {@code null}, or an
+   *         empty map if the input list is empty.
+   */
+  @Override
   public Map<String, List<String>> parseCommands(List<String> commands) {
 
     if (commands == null)
